@@ -66,46 +66,6 @@ setMethod("show", signature="status", function(object) {
 })
 
 
-## old S4 methods are kept around for backwards compat
-setMethod("statusText", signature="status", function(object) {
-  object$text
-})
-
-setMethod("favorited", signature="status", function(object, ...) {
-    object$favorited
-})
-
-setMethod("replyToSN", signature="status", function(object, ...) {
-    object$replyToSN
-})
-
-setMethod("created", signature="status", function(object, ...) {
-    object$created
-})
-
-setMethod("truncated", signature="status", function(object, ...) {
-    object$truncated
-})
-
-setMethod("replyToSID", signature="status", function(object, ...) {
-    object$replyToSID
-})
-
-setMethod("id", signature="status", function(object, ...){
-    object$id
-})
-
-setMethod("replyToUID", signature="status", function(object, ...) {
-    object$replyToUID
-})
-
-setMethod("statusSource", signature="status", function(object, ...) {
-    object$statusSource
-})
-
-setMethod("screenName", signature="status", function(object, ...) {
-    object$screenName
-})
 
 setRefClass("user",
             fields = list(
@@ -147,14 +107,15 @@ setRefClass("user",
                   else {
                     created <<- twitterDateToPOSIX(json[['created_at']])
                   }
-                  if (is.null(json[['protected']]))
-                    protected <<- TRUE
-                  else
+                  if ((is.null(json[['protected']])) || (json[['protected']] == FALSE))
                     protected <<- FALSE
-                  if (is.null(json[['verified']]))
-                    verified <<- TRUE
                   else
+                    protected <<- TRUE
+
+                  if ((is.null(json[['verified']])) || (json[['verified']] == FALSE))
                     verified <<- FALSE
+                  else
+                    verified <<- TRUE
                   if (is.character(json[['screen_name']]))
                     screenName <<- json[['screen_name']]
                   if (!is.null(json[['id']]))
@@ -171,69 +132,11 @@ userFactory$accessors(names(userFactory$fields()))
 buildUser <- function(json)
   userFactory$new(json)
 
-setMethod("screenName", signature="user", function(object, ...) {
-    object$screenName
-})
 
 setMethod("show", signature="user", function(object) {
     print(screenName(object))
 })
 
-setMethod("description", signature="user", function(object, ...) {
-    object$description
-})
-
-setMethod("statusesCount", signature="user", function(object, ...) {
-    object$statusesCount
-})
-
-setMethod("tweetCount", signature="user", function(object, ...) {
-    statusesCount(object)
-})
-
-setMethod("followersCount", signature="user", function(object, ...) {
-    object$followersCount
-})
-
-setMethod("favoritesCount", signature="user", function(object, ...) {
-    object$favoritesCount
-})
-
-setMethod("friendsCount", signature="user", function(object, ...) {
-    object$friendsCount
-})
-
-setMethod("userURL", signature="user", function(object, ...) {
-    object$url
-})
-
-setMethod("name", signature="user", function(object, ...) {
-    object$name
-})
-
-setMethod("created", signature="user", function(object, ...) {
-    object$created
-})
-
-setMethod("protected", signature="user", function(object, ...) {
-    object$protected
-})
-
-setMethod("verified", signature="user", function(object, ...) {
-    object$verified
-})
-
-setMethod("location", signature="user", function(object, ...) {
-    object$location
-})
-
-setMethod("id", signature="user", function(object, ...) {
-    object$id
-})
-
-setMethod("lastStatus", signature="user", function(object, ...) {
-    object$lastStatus
-})
 
 setRefClass("directMessage",
             fields = list(
